<p align="center"><img src="https://raw.githubusercontent.com/lucas-labs/satlite/refs/heads/master/.github/media/satlite.svg" height="32"></p>



<p align="center">
<a href="https://pypi.org/project/satlite/"><img alt="PyPI - Downloads" src="https://img.shields.io/pypi/l/satlite?style=flat-square&logoColor=%23ffffff&logo=python&labelColor=%23020101&color=%23ffffff"></a>&nbsp
<a href="https://pypi.org/project/satlite/">
<img alt="PyPI - Version" src="https://img.shields.io/pypi/v/satlite?style=flat-square&logoColor=%23ffffff&logo=python&labelColor=%23020101&color=%23ffffff">
</a>
</p>

<br>
<br>
<p align="center">tuki 😎</p>

<br>
<br>

> [!WARNING]  
> This is a work in progress.